Stan Math Library: stan/math/rev/mat/functor/cvodes_utils.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
cvodes_utils.hpp File Reference
`#include <cvodes/cvodes.h>`
`#include <cvodes/cvodes_band.h>`
`#include <cvodes/cvodes_dense.h>`
`#include <nvector/nvector_serial.h>`
`#include <sstream>`
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
void | stan::math::cvodes_silent_err_handler (int error_code, const char *module, const char *function, char *msg, void *eh_data)
void | stan::math::cvodes_check_flag (int flag, const std::string &func_name)
void | stan::math::cvodes_set_options (void *cvodes_mem, double rel_tol, double abs_tol, long int max_num_steps)

[ Stan Home Page ] © 2011–2016, Stan Development Team.